@@ -1,10 +1,121 @@
-`arima` <-
-function (x, order = c(0, 0, 0), seasonal = list(order = c(0, 
+'arima' <- function (x, order = c(0, 0, 0), seasonal = list(order = c(0, 
     0, 0), period = NA), xreg = NULL, include.mean = TRUE, transform.pars = TRUE, 
     fixed = NULL, init = NULL, method = c("CSS-ML", "ML", "CSS"), 
     n.cond, optim.control = list(), kappa = 1e+06, io = NULL, 
     xtransf, transfer = NULL) 
 {
+#
+#  This function is based on the arima function of the stats package
+#  of R. Below the copright statement of the arima function is reproduced. 
+#
+#  File src/library/stats/R/arima.R
+#  Part of the R package, http://www.R-project.org
+#
+#  Copyright (C) 2002-12 The R Core Team
+#
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  A copy of the GNU General Public License is available at
+#  http://www.r-project.org/Licenses/
+
+#
+# (arimax) Date: April, 18, 2006
+# Revised: August 15, 2006, Oct, 26, 2012
+
+deriv=function(u){
+#
+# compute the derivative of the transformation from u to phi given on p. 128
+# of Jones (1993) "Longitudinal Data with Serial Correlation: a state-space approach.
+#
+p=length(u)
+if(p<=1) return(2*exp(-u)/(1+exp(-u))^2)
+A=diag(as.vector(2*exp(-u)/(1+exp(-u))^2))
+pacf=(1-exp(-u))/(1+exp(-u))
+init=diag(as.vector(rep(1,p)))
+fd=NULL
+for ( i in 1:p) {
+oldphi=pacf[1]
+oldderiv=init[i,]
+for (k in 2:p) {
+mult=pacf[k]
+newphi=rep(NA,k)
+newderiv=rep(NA,k)
+newphi[k]=pacf[k]
+newderiv[k]=init[i,k]
+mult1=newderiv[k]
+for (j in 1: (k-1)) {
+newphi[j]=oldphi[j]-mult*oldphi[k-j]
+newderiv[j]=oldderiv[j]-mult*oldderiv[k-j]-mult1*oldphi[k-j]
+}
+oldphi=newphi
+oldderiv=newderiv
+}
+fd=rbind(fd, newderiv)
+}
+A%*%fd
+}
+
+difpar=function(par,arma){
+#
+# compute the first derivative matrix of the transformation from (u,U) to 
+# (phi, Phi).
+#
+res=diag(length(par))
+ if(arma[1]) res[1:arma[1],1:arma[1]]=(deriv(par[1:arma[1]]))
+ if(arma[3]) {indx=sum(arma[c(1,2)])+seq(arma[3])
+              res[indx,indx]=(deriv(par[indx]))}
+res
+}
+
+undotrans=function(par,arma){
+#
+# compute the transformation from (u,U) to (phi,Phi).
+#
+      if(arma[1]) par[1:arma[1]]=levinson(par[1:arma[1]])
+      if(arma[3]) par[sum(arma[c(1,2)])+seq(arma[3])]=levinson(par[sum(arma[c(1,2)])+seq(arma[3])])
+par
+}
+
+pacfparm=function(phi){
+#
+# compute the transformation from phi to u.
+#
+res=stats:::ARMAacf(ar=phi,lag.max=length(phi),pacf=TRUE)
+log((1+res)/(1-res))
+}
+
+transformpar=function(par,arma){
+#
+# conpute the transformation from (phi,Phi) to (u,U).
+#
+ if(arma[1]) par[1:arma[1]]=pacfparm(par[1:arma[1]])
+ if(arma[3]) par[sum(arma[c(1,2)])+seq(arma[3])]=pacfparm(par[sum(arma[c(1,2)])+seq(arma[3])])
+ par
+}
+ 
+
+conv=function(x,y){m=length(x)+length(y)-1
+         res=rep(0,m)
+         fres=res
+         n=length(x)
+         indx=1:n
+         for (i in y) {
+            res1=res
+            res1[indx]=x*i
+            fres=fres+res1
+            indx=indx+1
+          }
+fres
+}
+    conv1=function(x, period=1){c(x,rep(0, period))-c(rep(0, period),x)}
     if (!missing(transfer)) {
         for (i in seq(length(transfer))) transfer[[i]][2] = transfer[[i]][2] + 
             1
@@ -23,12 +134,12 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
         x
     }
     armafilter = function(x, phi, theta, Delta) {
-        if (length(theta) > 0) 
-            x = filter(x, filter = theta, side = 1, method = "convolution")
-        if (length(phi) > 0 && any(phi != 0)) 
-            x = filter(x, filter = phi, side = 1, method = "recursive")
         if (length(Delta) > 0) 
-            x = filter(x, filter = Delta, side = 1, method = "recursive")
+            x = filter(x, filter = Delta, sides = 1, method = "recursive")
+        if (length(phi) > 0 && any(phi != 0)) 
+            x = filter(x, filter = phi, sides = 1, method = "recursive")
+        if (length(theta) > 0)  
+            x = filter(x, filter = theta, sides = 1, method = "convolution")
         x
     }
     makePulse = function(point, xtsp) {
@@ -66,61 +177,147 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
         }
         x
     }
-    `%+%` <- function(a, b) .Call("TSconv", a, b, PACKAGE = "stats")
-    upARIMA <- function(mod, phi, theta) {
-        p <- length(phi)
-        q <- length(theta)
-        mod$phi <- phi
-        mod$theta <- theta
-        r <- max(p, q + 1)
-        if (p > 0) 
-            mod$T[1:p, 1] <- phi
-        if (r > 1) 
-            mod$Pn[1:r, 1:r] <- .Call("getQ0", phi, theta, PACKAGE = "stats")
-        else if (p > 0) 
-            mod$Pn[1, 1] <- 1/(1 - phi^2)
-        else mod$Pn[1, 1] <- 1
-        mod$a[] <- 0
-        mod
-    }
-    arimaSS <- function(y, mod) {
-        .Call("ARIMA_Like", y, mod$phi, mod$theta, mod$Delta, 
-            mod$a, mod$P, mod$Pn, as.integer(0), TRUE, PACKAGE = "stats")
-    }
-    armafn <- function(p, trans) {
+
+
+     btrarma = function(par, arma,trans){
+      if(trans) {
+      if(arma[1]) par[1:arma[1]]=levinson(par[1:arma[1]])
+      if(arma[3]) par[sum(arma[c(1,2)])+seq(arma[3])]=levinson(par[sum(arma[c(1,2)])+seq(arma[3])])
+}
+      if(arma[1]) phi=c(1, -par[1:arma[1]]) else phi=1
+      if(arma[3]) {Phi=c(1, -par[sum(arma[c(1,2)])+seq(arma[3])])
+             zero=matrix(0, nrow=arma[5]-1, ncol=length(Phi))
+             Phi=rbind(Phi, zero)
+             Phi=as.vector(Phi)
+             Phi=Phi[-seq(length(Phi)-arma[5]+2, length(Phi))]} else Phi=1
+      phi=conv(phi, Phi)
+      phi=-phi[-1]
+
+      if(arma[2]) theta=c(1, par[arma[1]+seq(arma[2])]) else theta=1
+      if(arma[4]) {Theta=c(1, par[sum(arma[c(1,2,3)])+seq(arma[4])])
+             zero=matrix(0, nrow=arma[5]-1, ncol=length(Theta))
+             Theta=rbind(Theta, zero)
+             Theta=as.vector(Theta)
+             Theta=Theta[-seq(length(Theta)-arma[5]+2, length(Theta))]} else Theta=1
+      theta=conv(theta, Theta)
+      theta=theta[-1]
+
+      list(phi=phi, theta=theta, par=par)
+      }
+
+levinson=function(u){
+#
+# compute u to phi
+#
+pacf=(1-exp(-u))/(1+exp(-u))
+p=length(u)
+if (p<=1) return(pacf) else {
+oldphi=pacf
+for (k in 2:p) {
+mult=pacf[k]
+newphi=rep(NA,k)
+newphi[k]=pacf[k]
+for (j in 1: (k-1)) {
+newphi[j]=oldphi[j]-mult*oldphi[k-j]
+}
+oldphi=newphi
+}
+}
+newphi
+}
+
+
+
+
+     armafn <- function(p, trans) {
         par <- coef
         par[mask] <- p
-        trarma <- .Call("ARIMA_transPars", par, arma, trans, 
-            PACKAGE = "stats")
-        Z <- upARIMA(mod, trarma[[1]], trarma[[2]])
-        if (ncxreg > 0) {
+        trarma <- btrarma(par, arma,trans)
+        par=trarma$par
+
+        Z <- makeARIMA(trarma[[1]], trarma[[2]], Delta, kappa)
+        r=max(length(Z$phi), length(Z$theta)+1)
+        if (r > 1) {
+            T1=Z$T[1:r,1:r]
+            V1=Z$V[1:r,1:r]
+            Z$Pn[1:r, 1:r] <- solve(diag(r*r)-T1%x%T1, as.vector(V1))
+            }
+        else if (length(Z$phi) > 0) 
+            Z$Pn[1, 1] <- 1/(1 - Z$phi^2)
+        else Z$Pn[1, 1] <- 1
+        Z$a[] <- 0
+         if (ncxreg > 0) {
             nxreg = checkIO(xreg, phi = Z$phi, theta = Z$theta, 
                 Delta = Z$Delta)
             x <- x - nxreg %*% par[narma + (1:ncxreg)]
         }
         if (ntransf.term) 
             x = upx(x, par)
-        res <- .Call("ARIMA_Like", x, Z$phi, Z$theta, Z$Delta, 
-            Z$a, Z$P, Z$Pn, as.integer(0), FALSE, PACKAGE = "stats")
-        s2 <- res[1]/res[3]
-        0.5 * (log(s2) + res[2]/res[3])
+        res=stats:::arima(x, order=order, seasonal=seasonal, fixed=par[1:narma],method='ML', include.mean=FALSE,transform.pars =FALSE)
+        (-2*res$loglik-n.used*(1+log(2*pi)))/(2*n.used)
     }
-    armaCSS <- function(p) {
+
+     armafn1 <- function(p, trans) {
+        par <- coef
+        par[mask] <- p
+        trarma <- btrarma(par, arma, trans)
+        par=trarma$par
+        Z <- makeARIMA(trarma[[1]], trarma[[2]], Delta, kappa)
+        r=max(length(Z$phi), length(Z$theta)+1)
+        if (r > 1) {
+            T1=Z$T[1:r,1:r]
+            V1=Z$V[1:r,1:r]
+            Z$Pn[1:r, 1:r] <- solve(diag(r*r)-T1%x%T1, as.vector(V1))
+            }
+        else if (length(Z$phi) > 0) 
+            Z$Pn[1, 1] <- 1/(1 - Z$phi^2)
+        else Z$Pn[1, 1] <- 1
+        Z$a[] <- 0
+         if (ncxreg > 0) {
+            nxreg = checkIO(xreg, phi = Z$phi, theta = Z$theta, 
+                Delta = Z$Delta)
+            x <- x - nxreg %*% par[narma + (1:ncxreg)]
+        }
+        if (ntransf.term) 
+            x = upx(x, par)
+        res=stats:::arima(x, order=order, seasonal=seasonal, fixed=par[1:narma],method='ML', include.mean=FALSE,transform.pars =FALSE)
+        res
+    }
+
+
+    armaCSS <- function(p, trans) {
         par <- as.double(fixed)
         par[mask] <- p
-        trarma <- .Call("ARIMA_transPars", par, arma, FALSE, 
-            PACKAGE = "stats")
-        if (ncxreg > 0) {
+        trarma <- btrarma(par, arma,trans)
+        par=trarma$par
+        Z <- makeARIMA(trarma[[1]], trarma[[2]], Delta, kappa)
+                if (ncxreg > 0) {
             nxreg = checkIO(xreg, phi = trarma[[1]], theta = trarma[[2]], 
                 Delta = Delta)
             x <- x - nxreg %*% par[narma + (1:ncxreg)]
         }
         if (ntransf.term) 
             x = upx(x, par)
-        res <- .Call("ARIMA_CSS", x, arma, trarma[[1]], trarma[[2]], 
-            as.integer(ncond), FALSE, PACKAGE = "stats")
-        0.5 * log(res)
-    }
+        res=stats:::arima(x, order=order, seasonal=seasonal, fixed=par[1:narma],method='CSS', include.mean=FALSE,transform.pars =FALSE)$sigma2
+        0.5*log(res)   
+ }
+    armaCSS1 <- function(p,trans) {
+        par <- as.double(fixed)
+        par[mask] <- p
+        trarma <- btrarma(par, arma, trans)
+        par=trarma$par
+        Z <- makeARIMA(trarma[[1]], trarma[[2]], Delta, kappa)
+                if (ncxreg > 0) {
+            nxreg = checkIO(xreg, phi = trarma[[1]], theta = trarma[[2]], 
+                Delta = Delta)
+            x <- x - nxreg %*% par[narma + (1:ncxreg)]
+        }
+        if (ntransf.term) 
+            x = upx(x, par)
+        stats:::arima(x, order=order, seasonal=seasonal, fixed=par[1:narma],method='CSS', include.mean=FALSE,transform.pars =FALSE)
+            }
+
+
     arCheck <- function(ar) {
         p <- max(which(c(1, -ar) != 0)) - 1
         if (!p) 
@@ -143,6 +340,8 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
         for (r in roots) x <- c(x, 0) - c(0, x)/r
         c(Re(x[-1]), rep(0, q - q0))
     }
+
+
     series <- deparse(substitute(x))
     if (NCOL(x) > 1) 
         stop("only implemented for univariate time series")
@@ -174,11 +373,13 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
     if (is.null(seasonal$period) || is.na(seasonal$period) || 
         seasonal$period == 0) 
         seasonal$period <- frequency(x)
+
     arma <- as.integer(c(order[-2], seasonal$order[-2], seasonal$period, 
         order[2], seasonal$order[2]))
     narma <- sum(arma[1:4])
     xtsp <- tsp(x)
     tsp(x) <- NULL
+
     Pm = NULL
     if (!missing(io)) {
         Pm = sapply(io, makePulse, xtsp)
@@ -188,17 +389,19 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
             deparse(name1[[i]]), sep = "-"))
         colnames(Pm) = namev
     }
+
     Delta <- 1
-    for (i in seq(len = order[2])) Delta <- Delta %+% c(1, -1)
-    for (i in seq(len = seasonal$order[2])) Delta <- Delta %+% 
-        c(1, rep(0, seasonal$period - 1), -1)
+    for (i in seq(len = order[2])) Delta <- conv1(Delta)
+    for (i in seq(len = seasonal$order[2])) Delta <- conv1(Delta,period=seasonal$period)
     Delta <- -Delta[-1]
     nd <- order[2] + seasonal$order[2]
     n.used <- sum(!is.na(x)) - length(Delta)
+
     if(!is.null(xreg)) xreg=data.frame(xreg)
     if (!is.null(xreg)) 
         xreg = as.matrix(xreg)
     xreg = cbind(xreg, Pm)
+
     if (is.null(xreg)) {
         ncxreg <- 0
     }
@@ -219,6 +422,7 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
         xreg <- cbind(intercept = rep(1, n), xreg = xreg)
         ncxreg <- ncxreg + 1
     }
+
     ntransf = 0
     ntransf.term = 0
     ct = NULL
@@ -253,6 +457,7 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
         if (anyna) 
             method <- "ML"
     }
+
     if (method == "CSS" || method == "CSS-ML") {
         ncond <- order[2] + seasonal$order[2] * seasonal$period
         ncond1 <- order[1] + seasonal$period * seasonal$order[1]
@@ -261,10 +466,12 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
         else ncond + ncond1
     }
     else ncond <- 0
+
     if (is.null(fixed)) 
         fixed <- rep(as.numeric(NA), narma + ncxreg + ntransf)
     else if (length(fixed) != narma + ncxreg + ntransf) 
         stop("wrong length for 'fixed'")
+ 
     mask <- is.na(fixed)
     no.optim <- !any(mask)
     if (no.optim) 
@@ -276,8 +483,10 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
             transform.pars <- FALSE
         }
     }
+
     init0 <- rep(0, narma)
     parscale <- rep(1, narma)
+ 
     if (ncxreg) {
         cn <- colnames(xreg)
         orig.xreg <- (ncxreg == 1) || any(!mask[narma + 1:ncxreg])
@@ -299,6 +508,7 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
         }
         parscale <- c(parscale, 10 * ses)
     }
+
     if (ntransf) {
         init0 = c(init0, rep(0, ntransf))
     }
@@ -309,8 +519,10 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
             parscale = c(parscale, rep(10 * ses, sum(transfer[[i]])))
         }
     }
+
     if (n.used <= 0) 
         stop("too few non-missing observations")
+
     if (!is.null(init)) {
         if (length(init) != length(init0)) 
             stop("'init' is of the wrong length")
@@ -323,38 +535,28 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
             if (arma[3] > 0) 
                 if (!arCheck(init[sum(arma[1:2]) + 1:arma[3]])) 
                   stop("non-stationary seasonal AR part")
-            if (transform.pars) 
-                init <- .Call("ARIMA_Invtrans", as.double(init), 
-                  arma, PACKAGE = "stats")
+            if (transform.pars) init=transformpar(init, arma)
         }
     }
     else init <- init0
+
     coef <- as.double(fixed)
+
     if (!("parscale" %in% names(optim.control))) 
         optim.control$parscale <- parscale[mask]
+
     if (method == "CSS") {
         res <- if (no.optim) 
             list(convergence = 0, par = numeric(0), value = armaCSS(numeric(0)))
         else optim(init[mask], armaCSS, method = "BFGS", hessian = TRUE, 
-            control = optim.control)
+            control = optim.control, trans=transform.pars)
         if (res$convergence > 0) 
             warning("possible convergence problem: optim gave code=", 
                 res$convergence)
         coef[mask] <- res$par
-        trarma <- .Call("ARIMA_transPars", coef, arma, FALSE, 
-            PACKAGE = "stats")
-        mod <- makeARIMA(trarma[[1]], trarma[[2]], Delta, kappa)
-        if (ncxreg > 0) {
-            nxreg = checkIO(xreg, phi = trarma[[1]], theta = trarma[[2]], 
-                Delta = Delta)
-            x <- x - nxreg %*% coef[narma + (1:ncxreg)]
-        }
-        if (ntransf.term) 
-            x = upx(x, coef)
-        arimaSS(x, mod)
-        val <- .Call("ARIMA_CSS", x, arma, trarma[[1]], trarma[[2]], 
-            as.integer(ncond), TRUE, PACKAGE = "stats")
-        sigma2 <- val[[1]]
+        val <- armaCSS1(res$par, transform.pars)
+        sigma2 <- val$sigma2
+        mod = val$mod  
         var <- if (no.optim) 
             numeric(0)
         else solve(res$hessian * n.used)
@@ -362,11 +564,12 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
     else {
         if (method == "CSS-ML") {
             res <- if (no.optim) 
-                list(convergence = 0, par = numeric(0), value = armaCSS(numeric(0)))
+                list(convergence = 0, par = numeric(0), value = armaCSS(numeric(0), trans=FALSE))
             else optim(init[mask], armaCSS, method = "BFGS", 
-                hessian = FALSE, control = optim.control)
-            if (res$convergence == 0) 
-                init[mask] <- res$par
+                hessian = FALSE, control = optim.control, trans=transform.pars)
+           if (res$convergence == 0) { 
+                if(transform.pars) res$par=undotrans(res$par, arma)
+                init[mask] <- res$par} 
             if (arma[1] > 0) 
                 if (!arCheck(init[1:arma[1]])) 
                   stop("non-stationary AR part from CSS")
@@ -375,8 +578,9 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
                   stop("non-stationary seasonal AR part from CSS")
             ncond <- 0
         }
-        if (transform.pars) {
-            init <- .Call("ARIMA_Invtrans", init, arma, PACKAGE = "stats")
+
+         if (transform.pars) {
+             init=transformpar(init, arma)
             if (arma[2] > 0) {
                 ind <- arma[1] + 1:arma[2]
                 init[ind] <- maInvert(init[ind])
@@ -386,18 +590,19 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
                 init[ind] <- maInvert(init[ind])
             }
         }
-        trarma <- .Call("ARIMA_transPars", init, arma, transform.pars, 
-            PACKAGE = "stats")
+        trarma <- btrarma(init, arma, transform.pars)
         mod <- makeARIMA(trarma[[1]], trarma[[2]], Delta, kappa)
         res <- if (no.optim) 
             list(convergence = 0, par = numeric(0), value = armafn(numeric(0), 
                 as.logical(transform.pars)))
         else optim(init[mask], armafn, method = "BFGS", hessian = TRUE, 
             control = optim.control, trans = as.logical(transform.pars))
+        
         if (res$convergence > 0) 
             warning("possible convergence problem: optim gave code=", 
                 res$convergence)
-        coef[mask] <- res$par
+       coef[mask] <- res$par
+
         if (transform.pars) {
             if (arma[2] > 0) {
                 ind <- arma[1] + 1:arma[2]
@@ -417,30 +622,22 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
                 res$convergence <- oldcode
                 coef[mask] <- res$par
             }
-            A <- .Call("ARIMA_Gradtrans", as.double(coef), arma, 
-                PACKAGE = "stats")
-            A <- A[mask, mask]
+
+             A = difpar(as.double(coef), arma)
+             A <- A[mask, mask]
             var <- t(A) %*% solve(res$hessian * n.used) %*% A
-            coef <- .Call("ARIMA_undoPars", coef, arma, PACKAGE = "stats")
+            coef = undotrans(coef, arma)
         }
         else var <- if (no.optim) 
             numeric(0)
         else solve(res$hessian * n.used)
-        trarma <- .Call("ARIMA_transPars", coef, arma, FALSE, 
-            PACKAGE = "stats")
-        mod <- makeARIMA(trarma[[1]], trarma[[2]], Delta, kappa)
-        if (ncxreg > 0) {
-            nxreg = checkIO(xreg, phi = trarma[[1]], theta = trarma[[2]], 
-                Delta = Delta)
-            x = x - nxreg %*% coef[narma + (1:ncxreg)]
-        }
-        if (ntransf.term) 
-            x = upx(x, coef)
-        val = arimaSS(x, mod)
-        sigma2 <- val[[1]][1]/n.used
-    }
-    value <- 2 * n.used * res$value + n.used + n.used * log(2 * 
-        pi)
+         val = armafn1(res$par,as.logical(transform.pars)) 
+         sigma2 <- val$sigma2 
+         mod = val$mod   
+}
+
+    value <-  2 * n.used * res$value + n.used + n.used * log(2 * 
+        pi)    
     aic <- if (method != "CSS") 
         value + 2 * sum(mask)
     else NA
@@ -466,9 +663,11 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
     }
     nm = c(nm, ct)
     names(coef) <- nm
+
+
     if (!no.optim) 
         dimnames(var) <- list(nm[mask], nm[mask])
-    resid <- val[[2]]
+    resid <- val$residuals
     tsp(resid) <- xtsp
     class(resid) <- "ts"
     res <- list(coef = coef, sigma2 = sigma2, var.coef = var, 
@@ -477,5 +676,4 @@ function (x, order = c(0, 0, 0), seasonal = list(order = c(0,
         code = res$convergence, n.cond = ncond, model = mod)
     class(res) <- c("Arimax", "Arima")
     res
-}
-
+}
\ No newline at end of file
