@@ -2,9 +2,7 @@ tsdiag.Arima <-
 function (object, gof.lag, tol = 0.1, col = "red", omit.initial = TRUE, 
     ...) 
 {
-    
-    opar = par()
-    par(mfrow = c(3, 1), mar = c(3, 4, 3, 2) + 0.1, oma = c(1, 
+    opar=par(mfrow = c(3, 1), mar = c(3, 4, 3, 2) + 0.1, oma = c(1, 
         0, 2, 0))
     n = length(eval(object$call[[2]]))
     if (missing(gof.lag)) 
@@ -29,7 +27,7 @@ function (object, gof.lag, tol = 0.1, col = "red", omit.initial = TRUE,
     abline(h = -h1, lty = 2, col = col)
     abline(h = 0)
     acf(as.numeric(residuals), lag.max = lag.max, ylab = "ACF of Residuals", 
-        ci.col = col,main='', ...)
+        ci.col = col, main = "", ...)
     ar = phi
     ma = c(1, theta)
     psiv = rep(0, lag.max)
@@ -40,8 +38,8 @@ function (object, gof.lag, tol = 0.1, col = "red", omit.initial = TRUE,
     psiv = psiv[-1]
     test = abs(psiv) < tol
     test = rev(cumprod(rev(test)))
-    if (any(test)) 
-        k = (seq(test)[test == 1])[1]
+    if (any(test==1)) 
+        k = (seq(along.with=test)[test == 1])[1]
     else stop("increase gof.lag as psi weights are not small enough for the Ljung-Box tests")
     lbv = rep(NA, lag.max)
     for (i in k:lag.max) {
@@ -50,6 +48,6 @@ function (object, gof.lag, tol = 0.1, col = "red", omit.initial = TRUE,
     plot(y = lbv, x = 1:lag.max, ylim = c(0, 1), pch = 21, ylab = "P-values", 
         xlab = "Number of lags", ...)
     abline(h = 0.05, lty = 2, col = col)
-    on.exit(par(opar))
+    par(opar)
     invisible()
-}
+}
\ No newline at end of file
